
class Routes(object):
    CHAMADA             = "/chamada"
    SMS                 = "/sms"
    AUDIO               = "/audio"
    COMPOSTO            = "/composto"
    CONFERENCIA         = "/conferencia"
    URA                 = "/ura"
    RAMAL               = "/ramal"
    TTS                 = "/tts"
    SALDO               = "/saldo"
    CONTA               = "/conta"
    CONTA_RECARGAS      = "/conta/recargas"
    CONTA_URL_RECARGA   = "/conta/urlrecarga"
    WEBHOOK             = "/webhook"
    WEBPHONE            = "/webphone"